@@ -1,6 +1,6 @@
 echo "Installing package dependencies inside docker:"
 echo ""
-poetry run pip install .
-echo $@
+poetry install 
+poetry run pip install pyspark
 poetry run pyspark
 
